@@ -1,6 +1,6 @@
 from .bayes import Bayesian as bayes
 from .pso import PSO as pso
-from .random import RandomSearch as random
+from .random_search import RandomSearch as random
 from .smac import SMAC as smac
 from .tpe import TPE as tpe
 
